==> gimageview-0.2.21.tar.gz: gimageview-0.2.21/plugins/thumbnail_view/detailview.h <==
/* -*- Mode: C; tab-width: 3; indent-tabs-mode: nil; c-basic-offset: 3 -*- */

/*
 * GImageView
 * Copyright (C) 2001 Takuro Ashie
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: detailview.h,v 1.1.2.2 2003/05/12 13:00:31 makeinu Exp $
 */

#ifndef __DETAILVIEW_H__
#define __DETAILVIEW_H__

#include "gimageview.h"
#include "fileload.h"
#include "thumbnail_view.h"

#define DETAIL_VIEW_LABEL  "Detail"
#define DETAIL_ICON_LABEL  "Detail + Icon"
#define DETAIL_THUMB_LABEL "Detail + Thumbnail"

#define DETAIL_DEFAULT_COLUMN_ORDER \
   "Name,Image size,Size (byte),Type,Cache type,Modification time,User,Group,Mode"

GList     *detailview_append_thumb_frames      (ThumbView     *tv,
                                                GList         *start,
                                                gchar         *dest_mode);
GtkWidget *detailview_add_thumbnail            (Thumbnail     *thumb,
                                                gchar         *dest_mode,
                                                ThumbLoadType  type);
gboolean   detailview_refresh_thumbnail        (Thumbnail     *thumb,
                                                ThumbLoadType  type);
void       detailview_redraw                   (ThumbView     *tv,
                                                gchar         *dest_mode,
                                                GtkWidget     *scroll_win,
                                                GList        **loadlist);
GtkWidget *detailview_resize                   (ThumbView     *tv);
void       detailview_adjust                   (ThumbView     *tv,
                                                Thumbnail     *thumb);
GtkWidget *detailview_create                   (ThumbView     *tv,
                                                gchar         *dest_mode);
void       detailview_remove_thumbview_data    (ThumbView     *tv);
gboolean   detailview_set_selection            (Thumbnail     *thumb,
                                                gboolean       select);
void       detailview_set_focus                (ThumbView     *Tv,
                                                Thumbnail     *thumb);
Thumbnail *detailview_get_focus                (ThumbView     *tv);
gboolean   detailview_thumbnail_is_in_viewport (ThumbView     *tv,
                                                Thumbnail     *thumb);

/* for preference */
gint   detailview_get_titles_num (void);
gchar *detailview_get_title      (gint idx);
gint   detailview_get_title_idx  (const gchar *title);
void   detailview_apply_config   (void);

#endif /* __DETAILVIEW_H__ */

==> gimageview_0.2.25.orig.tar.gz: gimageview-0.2.25/plugins/thumbnail_view/detailview.h <==
/* -*- Mode: C; tab-width: 3; indent-tabs-mode: nil; c-basic-offset: 3 -*- */

/*
 * GImageView
 * Copyright (C) 2001 Takuro Ashie
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: detailview.h,v 1.3 2003/06/18 09:26:54 makeinu Exp $
 */

#ifndef __DETAILVIEW_H__
#define __DETAILVIEW_H__

#include "gimageview.h"
#include "fileload.h"
#include "thumbnail_view.h"

#define DETAIL_VIEW_LABEL  "Detail"
#define DETAIL_ICON_LABEL  "Detail + Icon"
#define DETAIL_THUMB_LABEL "Detail + Thumbnail"

#define DETAIL_DEFAULT_COLUMN_ORDER \
   "Name,Image size,Size (byte),Type,Cache type,Modification time,User,Group,Mode"

GList     *detailview_append_thumb_frames      (ThumbView     *tv,
                                                GList         *start,
                                                gchar         *dest_mode);
GtkWidget *detailview_add_thumbnail            (GimvThumb     *thumb,
                                                gchar         *dest_mode,
                                                ThumbLoadType  type);
gboolean   detailview_refresh_thumbnail        (GimvThumb     *thumb,
                                                ThumbLoadType  type);
void       detailview_redraw                   (ThumbView     *tv,
                                                gchar         *dest_mode,
                                                GtkWidget     *scroll_win,
                                                GList        **loadlist);
GtkWidget *detailview_resize                   (ThumbView     *tv);
void       detailview_adjust                   (ThumbView     *tv,
                                                GimvThumb     *thumb);
GtkWidget *detailview_create                   (ThumbView     *tv,
                                                gchar         *dest_mode);
void       detailview_remove_thumbview_data    (ThumbView     *tv);
gboolean   detailview_set_selection            (GimvThumb     *thumb,
                                                gboolean       select);
void       detailview_set_focus                (ThumbView     *Tv,
                                                GimvThumb     *thumb);
GimvThumb *detailview_get_focus                (ThumbView     *tv);
gboolean   detailview_thumbnail_is_in_viewport (ThumbView     *tv,
                                                GimvThumb     *thumb);

/* for preference */
gint   detailview_get_titles_num (void);
gchar *detailview_get_title      (gint idx);
gint   detailview_get_title_idx  (const gchar *title);
void   detailview_apply_config   (void);

#endif /* __DETAILVIEW_H__ */
